#!/usr/bin/python
# _*_ coding: UTF-8 _*_


from distutils.core import setup


setup(
    name         = 'pylist',
    version      = '1.2.0',
    py_modules   = ['pylist'],
    author       = 'array',
    author_email = 'libingbing667@hotmail.com',
    url          = 'http://www.5000n.cn',
    description  = 'A simple printer of pylist lists',


    ) 
